@@ -15,25 +15,33 @@ plotKML.opts <- new.env(hash=TRUE, parent = parent.frame())
 
 # Find paths to external packages;
 paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "", python = "", show.paths = TRUE){ 
-     
-     require(utils)
-     
-     if(require(animation)){
-        convert <- ani.options("convert")
-     }
-     
+
+     #  Try locating SAGA GIS (R default setting)...
+     if(saga_cmd==""){
      if(require(RSAGA)){
-     if(.Platform$OS.type == "windows") { 
+     if(suppressWarnings(!is.null(x <- rsaga.env()))){ 
+     if(.Platform$OS.type == "windows") {
         saga_cmd <- shortPathName(normalizePath(paste(rsaga.env()$path, rsaga.env()$cmd, sep="/"))) 
      }
      else { 
         saga_cmd <- paste(rsaga.env()$path, rsaga.env()$cmd, sep="/") 
      } 
-        saga.version <- rsaga.get.version()
+        if(nzchar(saga_cmd)){
+          saga.version <- rsaga.get.version()
+        }
+     } else {
+        saga.version <- ""
+     }}}
+     
+     # Try locating path to ImageMagick (R default setting)...
+     if(convert==""){
+     if(require(animation)){
+        convert <- ani.options("convert")
      }
-    
-     im.dir <- NULL
+
+     # If it does not work, try getting the path from the OS:     
      if(is.null(convert)){
+        im.dir <- NULL
         if(.Platform$OS.type == "windows") {
         # get paths and check for ImageMagick
         paths <- strsplit(Sys.getenv('PATH')[[1]], ";")[[1]]
@@ -43,7 +51,7 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
         if(!length(x) == 0) {
           im.dir <- paths[grep(paths, pattern="ImageMagick")[1]]
           convert = shQuote(normalizePath(file.path(im.dir, "convert.exe")))
-          message(system(convert,  show.output.on.console = FALSE, intern = TRUE)[1])
+          if(show.paths){ message(system(convert,  show.output.on.console = FALSE, intern = TRUE)[1]) }
           }
         } # end checking for Imagemagick on Windows
         
@@ -52,23 +60,24 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
           if(!length(x <- grep(paths <- strsplit(Sys.getenv('PATH')[[1]], ":")[[1]], pattern="Magick"))==0) {
             im.dir <- paths[grep(paths, pattern="Magick")[1]]
             convert = "convert"
-            message(system(convert,  show.output.on.console = FALSE, intern = TRUE)[1])
-            # message(paste("Located ImageMagick from the path: \"", im.dir, "\"", sep=""))
+            if(show.paths){ message(system(convert,  show.output.on.console = FALSE, intern = TRUE)[1])
+            message("Located ImageMagick from the path") }
           }
         }
     
         if(is.null(im.dir)){ 
-        warning("Install ImageMagick and add to PATH. See http://imagemagick.org for more info.")
+          warning("Install ImageMagick and add to PATH. See http://imagemagick.org for more info.")
         convert = ""
         }
-     }
-     else { 
-     message(system(convert,  show.output.on.console = FALSE, intern = TRUE)[1])
-       }  
+     } else { 
+     if(show.paths){ message(system(convert,  show.output.on.console = FALSE, intern = TRUE)[1]) }
+    }
+    }  
   
-  # try to locate FWTools / Patyhon:
-  if(.Platform$OS.type == "windows") {
-
+    # try to locate FWTools / Patyhon:
+    if(.Platform$OS.type == "windows") {
+    if(gdalwarp==""|gdal_translate==""){
+    
      reg.paths <- names(utils::readRegistry("SOFTWARE"))
      # 64-bit software directory:
      x <- grep(reg.paths, pattern="WOW6432Node", ignore.case = TRUE)
@@ -77,7 +86,7 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
        if (nzchar(fw.path))  { 
           gdalwarp = shQuote(shortPathName(normalizePath(file.path(fw.path, "bin/gdalwarp.exe"))))
           gdal_translate = shQuote(shortPathName(normalizePath(file.path(fw.path, "bin/gdal_translate.exe"))))
-          message(paste("Located FWTools from the Registry Hive: \"", shortPathName(fw.path), "\"", sep="")) 
+          if(show.paths){ message(paste("Located FWTools from the Registry Hive: \"", shortPathName(fw.path), "\"", sep="")) }
        } 
      } 
 
@@ -87,7 +96,7 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
         length(fw.path2 <- list.files(file.path(prog, fw.dir), pattern = "^gdal_translate\\.exe$", full.names = TRUE, recursive = TRUE)) )  {
           gdalwarp = shQuote(shortPathName(normalizePath(fw.path[1])))
           gdal_translate = shQuote(shortPathName(normalizePath(fw.path2[1])))
-          message(paste("Located FWTools from the 'Program Files' directory: \"", shortPathName(fw.path), "\"", sep=""))
+          if(show.paths){ message(paste("Located FWTools from the 'Program Files' directory: \"", shortPathName(fw.path), "\"", sep="")) }
         } else if(nzchar(prog <- Sys.getenv("ProgramFiles(x86)")) &&
             length(fw.dir <- list.files(prog, "^FWTools.*")) &&
             length(fw.path <- list.files(file.path(prog, fw.dir), pattern = "^gdalwarp\\.exe$", full.names = TRUE, recursive = TRUE))  &&
@@ -95,7 +104,7 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
        {
         gdalwarp = shQuote(shortPathName(normalizePath(fw.path[1])))
         gdal_translate = shQuote(shortPathName(normalizePath(fw.path2[1])))
-        message(paste("Located FWTools from the 'Program Files' directory: \"", shortPathName(fw.path), "\"", sep=""))
+        if(show.paths){ message(paste("Located FWTools from the 'Program Files' directory: \"", shortPathName(fw.path), "\"", sep="")) }
      } 
      
      else {
@@ -103,16 +112,18 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
         gdalwarp = ""
         gdal_translate = ""    
        } 
-      }
+      }}
       
       # Python:
+      if(python==""){
+      x <- grep(reg.paths, pattern="WOW6432Node", ignore.case = TRUE)
       if(length(x)>0 & !inherits(try({ 
         py.paths <- utils::readRegistry(paste("SOFTWARE", reg.paths[x], "Python", sep="\\"), maxdepth=3)
         py.path = utils::readRegistry(paste("SOFTWARE", reg.paths[x], "Python", names(py.paths), names(py.paths[[1]]), "InstallPath", sep="\\"))[[1]] 
         }, silent = TRUE), "try-error")) {
           if (nzchar(py.path))  { 
             python = shQuote(shortPathName(normalizePath(file.path(py.path, "python.exe"))))
-            message(paste("Located Python from the Registry Hive: \"", shortPathName(py.path), "\"", sep="")) 
+            if(show.paths){ message(paste("Located Python from the Registry Hive: \"", shortPathName(py.path), "\"", sep="")) }
           } 
       } else { 
       if(!inherits(try({ 
@@ -121,7 +132,7 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
         }, silent = TRUE), "try-error")) {
         if (nzchar(py.path))  { 
           python = shQuote(shortPathName(normalizePath(file.path(py.path, "python.exe"))))
-          message(paste("Located Python from the Registry Hive: \"", shortPathName(py.path), "\"", sep="")) 
+          if(show.paths){ message(paste("Located Python from the Registry Hive: \"", shortPathName(py.path), "\"", sep="")) }
         }
       } 
            
@@ -129,80 +140,87 @@ paths <- function(gdalwarp = "", gdal_translate = "", convert = "", saga_cmd = "
         warning("Could not locate Python! Install program and add it to the Windows registry. See http://python.org for more info.")
         python = ""
       }}
+      }
        
-      # try to locate SAGA GIS (if not on a standard path):        
-      if(is.null(saga_cmd)){
-      if(nzchar(prog <- Sys.getenv("ProgramFiles")) &&
+      # 2nd chance to try to locate SAGA GIS (if not on a standard path):      
+      if(saga_cmd==""){
+      if(require(RSAGA)){
+        if(!nzchar(saga_cmd)&!nzchar(saga.version)){
+        if(nzchar(prog <- Sys.getenv("ProgramFiles")) &&
           length(saga.dir <- list.files(prog, "^SAGA*"))>0 &&
           length(saga_cmd <- list.files(file.path(prog, saga.dir), pattern = "^saga_cmd\\.exe$", full.names = TRUE, recursive = TRUE))>0  
-          )
-       {
-      myenv <- rsaga.env(path=shQuote(normalizePath(saga.dir[1])))
-      saga_cmd <- shortPathName(normalizePath(paste(myenv$path, myenv$cmd, sep="/")))
-      saga.version <- myenv$version 
-      message(paste("Located SAGA GIS ", saga.version, " from the 'Program Files' directory: \"", shortPathName(saga_cmd), "\"", sep=""))
-     }
-     else if (nzchar(prog <- Sys.getenv("ProgramFiles(x86)")) &&
+          ){
+        if(suppressWarnings(!is.null(myenv <- rsaga.env(path=shQuote(normalizePath(saga.dir[1])))))){ 
+          saga_cmd <- shortPathName(normalizePath(paste(myenv$path, myenv$cmd, sep="/")))
+          saga.version <- myenv$version 
+          if(show.paths){ message(paste("Located SAGA GIS ", saga.version, " from the 'Program Files' directory: \"", shortPathName(saga_cmd), "\"", sep="")) }
+     }} else{ if(nzchar(prog <- Sys.getenv("ProgramFiles(x86)")) &&
           length(saga.dir <- list.files(prog, "^SAGA*"))>0 &&
           length(saga_cmd <- list.files(file.path(prog, saga.dir), pattern = "^saga_cmd\\.exe$", full.names = TRUE, recursive = TRUE))>0   
-          )
-       {
-      myenv <- rsaga.env(path=shQuote(normalizePath(saga.dir[1])))
-      saga_cmd <- shortPathName(normalizePath(paste(myenv$path, myenv$cmd, sep="/")))
-      saga.version <- myenv$version 
-      message(paste("Located SAGA GIS ", saga.version, " from the 'Program Files' directory: \"", shortPathName(saga_cmd), "\"", sep=""))
+          ) {
+        if(suppressWarnings(!is.null(myenv <- rsaga.env(path=shQuote(normalizePath(saga.dir[1])))))){ 
+          saga_cmd <- shortPathName(normalizePath(paste(myenv$path, myenv$cmd, sep="/")))
+          saga.version <- myenv$version 
+          if(show.paths){ message(paste("Located SAGA GIS ", saga.version, " from the 'Program Files' directory: \"", shortPathName(saga_cmd), "\"", sep="")) }
+     }}
      }
       
-      if(is.null(saga_cmd)){
-      warning("Could not locate SAGA GIS! Install program and add it to the Windows registry. See http://www.saga-gis.org/en/ for more info.")
-      saga_vc = "" 
+     if(!nzchar(saga_cmd)){
+        warning("Could not locate SAGA GIS! Install program and add it to the Windows registry. See http://www.saga-gis.org/en/ for more info.")
+        saga_vc = "" 
       }   
      }
      else {
-       message(paste("Located SAGA GIS ", saga.version, " from the 'Program Files' directory: \"", shortPathName(saga_cmd), "\"", sep=""))  
+        if(show.paths){ message(paste("Located SAGA GIS ", saga.version, " from the 'Program Files' directory: \"", shortPathName(saga_cmd), "\"", sep="")) }
      }
+    }}
     }
     
     ## UNIX:
     else {
     
+    if(gdalwarp==""|gdal_translate==""){
     if(!length(x <- grep(paths <- strsplit(Sys.getenv('PATH')[[1]], ":")[[1]], pattern="FWTools"))==0) {
     fw.dir <- paths[grep(paths, pattern="FWTools")[1]]
     gdalwarp = "gdalwarp"
     gdal_translate = "gdal_translate"
-    message(paste("Located FWTools from the path: \"", fw.dir, "\"", sep=""))
+    if(show.paths){ message(paste("Located FWTools from the path: \"", fw.dir, "\"", sep="")) }
       }
     else { 
         warning("Install FWTools and add to PATH. See http://fwtools.maptools.org for more info.")
       gdalwarp = ""
       gdal_translate = ""
-      }
+    }
+    }
     
+    if(python==""){
     if(!length(x <- grep(paths <- strsplit(Sys.getenv('PATH')[[1]], ":")[[1]], pattern="Python"))==0) {
     py.dir <- paths[grep(paths, pattern="Python")[1]]
     python = "python"
-    message(paste("Located Python from the path: \"", py.dir, "\"", sep=""))
+    if(show.paths){ message(paste("Located Python from the path: \"", py.dir, "\"", sep="")) }
       }
     else { 
         warning("Install Python and add to PATH. See http://python.org for more info.")
         python = ""
-      }
+    }
+    }
     
+    if(convert==""){
     if(is.null(im.dir)){ 
         warning("Install ImageMagick and add to PATH. See http://imagemagick.org for more info.")
         convert = ""
-        }
+    }
+    }
 
-    if(is.null(saga_cmd)){
+    if(saga_cmd==""){
+    if(!nzchar(saga_cmd)){
         warning("Install SAGA GIS and add to PATH. See http://www.saga-gis.org for more info.")
-        saga_cmd = ""
         } 
     }
+    }
 
     lt <- data.frame(gdalwarp, gdal_translate, convert, python, saga_cmd, stringsAsFactors = FALSE)
-    if(show.paths){  
-    return(lt)  
-    }
+    return(lt)
 }
 
 ################## STANDARD SETTINGS ##############
@@ -234,11 +252,15 @@ plotKML.env <- function(
     silent = TRUE
     ){
     
-    require(RColorBrewer)
-    require(grDevices)
-    if(missing(colour_scale_numeric)) { colour_scale_numeric <- rev(brewer.pal(n = 5, name = "RdYlBu")) }
-    if(missing(colour_scale_factor)) { colour_scale_factor <- brewer.pal(n = 9, name = "Set1") }
-    if(missing(colour_scale_svar)) { colour_scale_svar <- brewer.pal(n = 5, name = "Oranges") }
+	brewer1 = c("#D7191C","#FDAE61","#FFFFBF","#ABD9E9","#2C7BB6")
+    #if(missing(colour_scale_numeric)) { colour_scale_numeric <- rev(brewer.pal(n = 5, name = "RdYlBu")) }
+    if(missing(colour_scale_numeric)) { colour_scale_numeric <- rev(brewer1) }
+	brewer2 = c("#E41A1C","#377EB8","#4DAF4A","#984EA3","#FF7F00","#FFFF33","#A65628","#F781BF","#999999")
+    #if(missing(colour_scale_factor)) { colour_scale_factor <- brewer.pal(n = 9, name = "Set1") }
+    if(missing(colour_scale_factor)) { colour_scale_factor <- brewer2 }
+	brewer3 = c("#FEEDDE","#FDBE85","#FD8D3C","#E6550D","#A63603")
+    #if(missing(colour_scale_svar)) { colour_scale_svar <- brewer.pal(n = 5, name = "Oranges") }
+    if(missing(colour_scale_svar)) { colour_scale_svar <- brewer3 }
     if(missing(ref_CRS)) { ref_CRS <- "+proj=longlat +datum=WGS84" }
     if(missing(NAflag)) { NAflag <- -99999 }
     if(missing(icon)) { icon <- "icon3.png" }   # "http://maps.google.com/mapfiles/kml/shapes/donut.png"
