@@ -67,17 +67,17 @@ readKML.GBIFdensity <- function(kml.file, gbif.url = FALSE, silent = FALSE){
   r <- raster(r.sp)
   # rasterize - convert points to a raster map:
   out.r <- rasterize(out, r, "nrecs", fun=mean)
-  out.r@layernames <- lname
+  names(out.r) <- lname
 
   if(gbif.url == TRUE){
   out2.r <- rasterize(out, r, "cellid")
   out2.r@data@isfactor <- TRUE
   out2.r@legend@values <- levels(as.factor(cellid))
-  out.r@layernames <- "cellid"
+  names(out.r) <- "cellid"
   out3.r <- rasterize(out, r, "taxonconceptkey")
   out3.r@data@isfactor <- TRUE
   out3.r@legend@values <- levels(as.factor(taxonconceptkey))
-  out3.r@layernames <- "taxonconceptkey"  
+  names(out3.r) <- "taxonconceptkey"  
   out.r <- brick(out.r, out2.r, out3.r)
   }
 
